@@ -3,7 +3,7 @@
 //! Must be used along with mungos, rocket with the json feature enabled, and probably serde. 
 //! Rocket must .manage an instance of Mungos.
 //! 
-//! The macro is accessed as ``` mungos_routes!("database name", "collection name", SerializableType, RequestGuard) ```, 
+//! The macro is accessed as ``` guarded_mungos_routes!("database name", "collection name", SerializableType, RequestGuard) ```, 
 //! where the database and collection names refer to your mongoDB database, and the SerializableType
 //! is the type of the collection schema. RequestGuard refers to a rocket request guard struct that you want 
 //! to guard your routes (such as authentication). 
@@ -25,7 +25,7 @@
 //! 
 //! rocket.build()
 //! 	.manage(Mungos::new(...))
-//! 	.mount("/", mungos_routes!("db name", "collection name", SerializableType, AuthGuard) )
+//! 	.mount("/", guarded_mungos_routes!("db name", "collection name", SerializableType, AuthGuard) )
 //! ```
 //! 
 //! The routes generated are: 
@@ -45,7 +45,7 @@
 macro_rules! guarded_mungos_routes {
 	($database:expr, $collection:expr, $TypeName:ty, $RequestGuard:ty) => {
 		{
-			use mungos::Mungos;
+			use mungos::{Mungos, Update};
 			use rocket::{State, serde::json::Json};
 
 			#[get("/")]
@@ -63,7 +63,6 @@ macro_rules! guarded_mungos_routes {
 					mungos.collection($database, $collection).get_one(id)
 						.await
 						.unwrap()
-						.unwrap()
 				)
 			}
 
@@ -81,7 +80,7 @@ macro_rules! guarded_mungos_routes {
 				data: Json<$TypeName>,
         _guard: $RequestGuard
 			) -> Json<$TypeName> {
-				Json(mungos.collection($database, $collection).update_one(id, data.into_inner())
+				Json(mungos.collection($database, $collection).update_one(id, Update::Regular(data.into_inner()))
 					.await
 					.unwrap())
 			}
